@@ -379,8 +379,6 @@ class PythonGrader(BaseGrader):
 
             # For non-numerical values
             if not sub_is_num and sub != ans:
-                print("non-numerical values")
-                print(k)
                 self.update_comment(key_val_comment)
                 self.passed = False
                 break_flag = True
@@ -450,24 +448,30 @@ class PandasGrader(BaseGrader):
 
     def grade_df(
         self,
+        sort_values_by=None,
         match_index=True,
-        match_index_col_order=True,
-        tolerance=0.0,
+        match_index_col_order=False,
+        tolerance=0.01,
         return_bool=False,
     ):
         """Evaluate submitted DataFrame.
 
         Parameters
         ----------
+        sort_values_by : str, list, default=None
+            If specified, submission and answer will be sorted by that column (or list
+            of columns) before evaluation. If ``"all_cols"``, DataFrame will be sorted
+            by a list of all columns (ordered alphabetically).
+
         match_index : bool, default=True
             Whether or not to consider the index of the submitted DataFrame. If
             ``False``, index is reset before it's evaluated.
 
-        match_index_col_order : bool, default=True
+        match_index_col_order : bool, default=False
             Whether or not to consider the order of the index and columns in the
             submitted DataFrame.
 
-        tolerance: int or float, default=0.0
+        tolerance: int or float, default=0.01
             For numerical values, what is the maximum allowed
             difference between ``submission`` and ``answer``? If ``tolerance=0.1``, values must be
             identical. If ``tolerance=0.1``, values must be within 10% of each
@@ -516,6 +520,24 @@ class PandasGrader(BaseGrader):
                 f"grade_df method can only be used with DataFrames submissions, not {type(self.submission).__name__}."
             )
 
+        if sort_values_by:
+            try:
+                if sort_values_by == "all_cols":
+                    # Sorts df cols alphabetically and then sorts rows by all cols
+                    self.submission = self.submission.sort_index(
+                        axis=1
+                    ).sort_values(by=self.submission.columns.tolist(), axis=0)
+                    self.answer = self.answer.sort_index(axis=1).sort_values(
+                        by=self.answer.columns.tolist(), axis=0
+                    )
+                else:
+                    self.submission.sort_values(sort_values_by, inplace=True)
+                    self.answer.sort_values(sort_values_by, inplace=True)
+            except KeyError:
+                raise KeyError(
+                    f"Either the submission or answer does not have column(s) {sort_values_by}."
+                )
+
         if not match_index:
             self.submission = self.submission.reset_index(drop=True)
             self.answer = self.answer.reset_index(drop=True)
@@ -556,9 +578,9 @@ class PandasGrader(BaseGrader):
     def grade_series(
         self,
         match_index=True,
-        match_index_order=True,
+        match_index_order=False,
         match_names=True,
-        tolerance=0.0,
+        tolerance=0.01,
         return_bool=False,
     ):
         """Evaluate submitted Series.
@@ -569,7 +591,7 @@ class PandasGrader(BaseGrader):
             Whether to consider the submission's index when evaluating against
             answer.
 
-        match_index_order : bool, default=True
+        match_index_order : bool, default=False
             Whether to consider the submission's index order when evaluating
             against answer. If ``False``, both submission and answer are sorted
             ascending.
@@ -577,7 +599,7 @@ class PandasGrader(BaseGrader):
         match_names : bool, default=True
             Whether to consider the submission's Series and Index names attributes.
 
-        tolerance: int or float, default=0.0
+        tolerance : int or float, default=0.01
             For numerical values, what is the maximum allowed
             difference between ``submission`` and ``answer``? If ``tolerance=0.0``,
             values must be identical. If ``tolerance=0.1``, values must be within 10%
@@ -675,7 +697,6 @@ class PandasGrader(BaseGrader):
             else:
                 return None
         except AssertionError as e:
-            print("Assertion Error", e)
             comment = self._clean_assert_message(e)
             self.update_comment(comment)
             if return_bool:
